# -*- coding:utf-8 -*-
"""
@Time        : 2023/3/2
@File        : util_log.py
@Author      : MysteriousMan
@version     : python 3
@Description : 日志
"""

import logging
import time
from colorlog import ColoredFormatter


class AutoLog:
    """
    通用日志
    """

    def __init__(self, filename, level_param):
        """
        初始化
        :param filename: 文件路径
        :param level_param: 打印级别 INFO WARNING ERROR CRITICAL
        """
        self.filename = f"{filename}-{time.strftime('%Y-%m-%d', time.localtime())}.log"  # 文件路径+日期
        self.level_param = level_param

    def log(self, message=""):
        logger = logging.getLogger(__name__)
        try:
            formatter = ColoredFormatter(  # 设置颜色&格式
                "%(log_color)s[%(levelname)s][%(asctime)s] %(message)s", datefmt=None, reset=True,
                log_colors={
                    'DEBUG': 'cyan',
                    'INFO': 'green',
                    'WARNING': 'yellow',
                    'ERROR': 'red',
                    'CRITICAL': 'black,bg_white'
                }
            )
            ch = logging.StreamHandler()  # 创建控制台
            ch.setFormatter(formatter)  # 对文件格式
            logger.addHandler(ch)  # 控制台句柄加入logger

            fh = logging.FileHandler(filename=self.filename, encoding="utf-8")  # 创建文件
            fh.setFormatter(logging.Formatter('[%(levelname)s][%(asctime)s]\t%(message)s'))  # 对文件格式
            logger.addHandler(fh)  # 文件句柄加入logger

            logger.setLevel(level=logging.INFO)  # 设置打印级别

            if self.level_param == 'DEBUG':
                logger.debug(message)
            elif self.level_param == 'INFO':
                logger.info(message)
            elif self.level_param == 'ERROR':
                logger.error(message)
            elif self.level_param == 'WARNING':
                logger.warning(message)
            elif self.level_param == 'CRITICAL':
                logger.critical(message)

            logger.removeHandler(fh)  # 删除文件句柄
            logger.removeHandler(ch)  # 移除控制台对象
            logging.shutdown()

        except:
            print('file exception')
        # finally:
        # fh.close()
        # kill_process_using_file(file_path)


if __name__ == '__main__':
    pass
    # Info = AutoLog(f"\\message_log\\info", level_param='INFO')
    # Warn = AutoLog(f"\\message_log\\warn", level_param='WARNING')
    # Error = AutoLog(f"\\message_log\\error", level_param='ERROR')
    # Critical = AutoLog(f"\\message_log\\critical", level_param='CRITICAL')



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
@Time        : 2023/3/2
@File        : util_assert.py
@Author      : MysteriousMan
@version     : python 3
@Description : 依赖库
               判断程序是否每次会更新依赖库，如有更新，则自动安装
"""
import os
import chardet


class InstallRequirements:
    """ 自动识别安装最新依赖库 """

    def __init__(self, version_path, path):
        """
        初始化
        Args:
            version_path: 版本控制文件
            path: 原始文件
        """
        self.version_library_comparisons_path = version_path
        self.requirements_path = path
        # 初始化时，获取最新的版本库
        self.get_latest_requirements()

    def get_latest_requirements(self):
        """ 获取最新的依赖库信息并保存到 requirements.txt """
        try:
            os.system("pip freeze > {}".format(self.requirements_path))
        except Exception as e:
            print(f"获取最新依赖库时出错: {e}")

    def read_version_library_comparisons_txt(self):
        """
        获取版本比对默认的文件
        @return: 文件内容
        """
        try:
            with open(self.version_library_comparisons_path, 'r', encoding="utf-8") as file:
                return file.read().strip(' ')
        except Exception as e:
            print(f"读取版本比对文件时出错: {e}")

    @classmethod
    def check_charset(cls, file_path):
        """获取文件的字符集"""
        try:
            with open(file_path, "rb") as file:
                data = file.read(4)
                charset = chardet.detect(data)['encoding']
            return charset
        except Exception as e:
            print(f"检测文件编码时出错: {e}")

    def read_requirements(self):
        """获取安装文件"""
        file_data = ""
        try:
            with open(
                    self.requirements_path,
                    'r',
                    encoding=self.check_charset(self.requirements_path)
            ) as file:
                for line in file:
                    if "[0m" in line:
                        line = line.replace("[0m", "")
                    file_data += line

            with open(
                    self.requirements_path,
                    "w",
                    encoding=self.check_charset(self.requirements_path)
            ) as file:
                file.write(file_data)
        except Exception as e:
            print(f"读取或写入 requirements 文件时出错: {e}")

        return file_data

    def text_comparison(self):
        """
        版本库比对
        @return:
        """
        read_version_library_comparisons_txt = self.read_version_library_comparisons_txt()
        read_requirements = self.read_requirements()
        if read_version_library_comparisons_txt == read_requirements:
            print("程序中未检查到更新版本库，已为您跳过自动安装库")
        # 程序中如出现不同的文件，则安装
        else:
            print("程序中检测到您更新了依赖库，已为您自动安装")
            try:
                os.system(f"pip install -r {self.requirements_path}")
                with open(self.version_library_comparisons_path, "w",
                          encoding=self.check_charset(self.requirements_path)) as file:
                    file.write(read_requirements)
            except Exception as e:
                print(f"安装依赖库或更新版本比对文件时出错: {e}")


if __name__ == '__main__':
    install_requirements = InstallRequirements(
        "/install_tool/version_library_comparisons.txt",
        "/requirements.txt"
    )
    install_requirements.text_comparison()



# -*- coding:utf-8 -*-
"""
@Time        : 2023/3/2
@File        : util_assert.py
@Author      : MysteriousMan
@version     : python 3
@Description : 断言
"""

from hamcrest import *


def assert_db(actual):
    """
    断言匹配对象不为()
    :param actual:
    :return:
    """
    assert_that(actual, is_not(()), reason="reason was 'Expected value is not none!'")


def assert_not_none(actual, url=None):
    """
    断言匹配对象不为空
    :param actual: 真实值
    :param url: 地址
    :return:
    """
    assert_that(actual, is_not(None), reason=f"url was '{url}'\nreason was 'Expected value is not none!'")


def assert_equals(actual, expect=None, url=None, info=None):
    """
    断言匹配相等对象
    :param actual: 真实值
    :param expect: 期望值
    :param url: 地址
    :param info: 断言结果日志记录对象(obj)
    :return:相等则不抛出异常，不相等则抛出异常
    """
    if expect:
        assert_that(
            actual, equal_to(expect),
            reason=f"url was '{url}'\nreason was 'Expected value is not equal to the actual value!'"
        )
        mes = "接口断言成功, 符合预期结果"
        mes = f"{mes} {url}\n" if url else f"{mes}\n"
        info.log(mes) if info else print(mes)
    else:
        pass


def assert_containString(actual, expect=None, url=None, info=None):
    """
    断言匹配字符串的一部分
    :param actual: 真实值
    :param expect: 期望值
    :param url: 地址
    :param info: 断言结果日志记录对象(obj)
    :return: 返回状态 True None
    :url
    """
    if expect:
        assert_that(
            actual, contains_string(str(expect)),
            reason=f"断言失败原因: '实际结果与期望结果不同!' \nurl was {url}"
        )
        mes = "接口断言成功, 符合预期结果"
        mes = f"{mes} {url}\n" if url else f"{mes}\n"
        info.log(mes) if info else print(mes)
        return True
    else:
        info.log(f"未进行接口返回断言!") if info else None
        return None


def assert_less(actual, expect=None, url=None, info=None):
    """
    断言数字小于预期
    :param actual: 真实值
    :param expect: 期望值
    :param url: 地址
    :param info: 断言结果日志记录对象(obj)
    :return:
    """
    if expect:
        assert_that(
            actual, less_than(expect),
            reason=f"url was '{url}'\nreason was 'Actual value is greater than or equal to the expected value!'"
        )
        mes = "接口断言成功, 符合预期结果"
        mes = f"{mes} {url}\n" if url else f"{mes}\n"
        info.log(mes) if info else print(mes)
    else:
        pass


if __name__ == '__main__':
    print(assert_containString(actual='123', expect='3'))




# -*- coding:utf-8 -*-
"""
@Time        : 2025/1/16 15:45
@File        : setup.py
@Author      : lyz
@Version     : python 3.11
@Description : 
"""
from setuptools import setup, find_packages

"""
读取 README.md 文件
"""
with open('PyUtilToolKits/README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()
print(f"Long description:\n{long_description}")

setup(
    name='PyUtilToolKits',  # 包名 别人安装时就是用此名来按照
    version='1.1.8',  # 包的版本号
    description='Python Utils',  # 包的介绍、概述
    author='MysteriousMan',  # 包的作者
    author_email='',  # 邮箱
    long_description=long_description,  # 项目的描述 读取README.md文件的信息
    long_description_content_type="text/markdown",  # 描述文档README的格式 一般md
    # url='https://github.com/your_username/my_package',  # 项目的 GitLab 地址或其他主页
    packages=find_packages(),  # Python导入包的列表 可以find_packages() 来自动收集
    keywords='kit',
    install_requires=[
        'colorlog==6.8.2',
        'PyHamcrest==2.1.0',
        'chardet==3.0.4'
    ],  # 其他依赖的约束
    license="MIT",  # 许可证
    # 这 需要去官网查，在下边提供了许可证连接 或者 你可以直接把我的粘贴走
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"],
    python_requires='>=3.10',  # Python的版本约束
)



# -*- coding:utf-8 -*-
"""
@Time        : 2023/3/2
@File        : __init__.py
@Author      : MysteriousMan
@version     : python 3
@Description : initialization
"""

from PyUtilToolKits import *

"""
__all__
:param : File name (no .py)
"""

__all__ = ["util_log", "util_assert", "util_requirements"]
